/*! theme.css */

body {
    padding-top: 50px;
    padding-bottom: 50px;
}

.terminal-mkdocs-main-grid {
    display: grid;
    grid-column-gap: 1.4em;
    grid-template-columns: auto;
    grid-template-rows: auto;
}

@media only screen and (min-width: 70em) {
    .terminal-mkdocs-main-grid {
        grid-template-columns: 4fr 9fr;
    }
}

.terminal-mkdocs-side-nav-item--active {
    font-style: italic;
}

.terminal-mkdocs-side-nav-section-no-index {
    color: var(--secondary-color);
}

.terminal-mkdocs-thin-border {
    border: solid !important;
    border-color: var(--secondary-color) !important;
    border-width: thin !important;
}

.terminal-mkdocs-tile-grid {
    display: grid;
    grid-gap: 1em;
    grid-template-rows: auto;
    grid-template-columns: repeat(
        auto-fit,
        minmax(calc(var(--page-width) / 6), 1fr)
    );
}

.terminal-mkdocs-tile {
    border: none !important;
}

.terminal-mkdocs-tile > figure > a {
    display: flex;
    justify-content: center;
    align-items: center;
}

/* ***************************************************************** */
/* Terminal.css Overrides */
/* ***************************************************************** */

/* don't display backticks on `code` items, just highlight */
code::after,
code::before {
    content: "" !important;
    display: inline;
}

/*! terminal.css | MIT License |  https://github.com/Gioni06/terminal.css/pull/36 */
blockquote > *:last-child {
    margin-bottom: 0;
}
  
  