<div class="container">
  <div class="terminal-nav">
    <nav>
      {% if nav|length>1 %}
        <ul class="terminal-mkdocs-side-nav-items">
            {% for nav_item in nav %}
              {% include "partials/side-nav-item.html" %}
            {% endfor %}
        </ul>
      {% endif %}
    </nav>
  </div>
</div>