<div class="container">
    <footer>
        {% if config.copyright %}
        <p class="text-center text-muted">{{ config.copyright }}</p>
        {% endif %} Site built with <a target="_blank" rel="noopener" href="http://www.mkdocs.org">MkDocs</a> and <a target="_blank" rel="noopener" href="https://github.com/ntno/mkdocs-terminal">Terminal for MkDocs</a>.
    </footer>
</div>