<section>
    {% if page and page.meta %}       
        {% set show_tiles_first = "true" if page.meta.show_tiles_first %}
        {% if page.meta.hide %}
            {% set hide_git_revision_date = "true" if "git_revision_date" in page.meta.hide %}
        {% endif %}
    {% endif %}

    {% if show_tiles_first %}
    {% include "partials/tiles.html" %}
    {% if page and page.content %}{{ page.content }}{% endif %}
    {% else %} 
    {% if page and page.content %}{{ page.content }}{% endif %}
    {% include "partials/tiles.html" %}
    {% endif %} 

    {% if not hide_git_revision_date %}
    {% include "partials/revision.html" %}
    {% endif %}
</section>