{% import 'macros/tile.j2' as tile_helper %}

{%- if page and page.meta -%}
{%- set show_tiles = "true" if page.meta.tiles -%}
{%- endif -%}
{%- if show_tiles -%}
<div class="terminal-mkdocs-tile-grid">
    {% for tile in page.meta.tiles -%}
    {{ tile_helper.make_tile( tile ) }}
    {% endfor %}
</div>
{%- endif -%}