/*! gruvbox_dark.css | MIT License | github.com/Gioni06/terminal.css/issues/9 */

:root {
    /* Background */
    --gb-dm-bg0: #282828;
    --gb-dm-bg0-hard: #1d2021;
    --gb-dm-bg0-soft: #32302f;
    --gb-dm-bg1: #3c3836;
    --gb-dm-bg2: #504945;
    --gb-dm-bg3: #665c54;
    --gb-dm-bg4: #7c6f64;

    /* Foreground */
    --gb-dm-fg0: #fbf1c7;
    --gb-dm-fg1: #ebdbb2;
    --gb-dm-fg2: #d5c4a1;
    --gb-dm-fg3: #bdae93;
    --gb-dm-fg4: #a89984;

    /* Colors */
    --gb-dm-dark-red: #cc241d;
    --gb-dm-dark-green: #98971a;
    --gb-dm-dark-yellow: #d79921;
    --gb-dm-dark-blue: #458588;
    --gb-dm-dark-purple: #b16286;
    --gb-dm-dark-aqua: #689d6a;
    --gb-dm-dark-orange: #d65d0e;
    --gb-dm-dark-gray: #928374;

    --gb-dm-light-red: #fb4934;
    --gb-dm-light-green: #b8bb26;
    --gb-dm-light-yellow: #fabd2f;
    --gb-dm-light-blue: #83a598;
    --gb-dm-light-purple: #d3869b;
    --gb-dm-light-aqua: #8ec07c;
    --gb-dm-light-orange: #f38019;
    --gb-dm-light-gray: #a89984;

    --global-font-size:        15px;
    --global-line-height:      1.4em;
    --global-space:            10px;
    --font-stack:              Menlo, Monaco, Lucida Console, Liberation Mono, DejaVu Sans Mono, Bitstream Vera Sans Mono, Courier New, monospace, serif;
    --mono-font-stack:         Menlo, Monaco, Lucida Console, Liberation Mono, DejaVu Sans Mono, Bitstream Vera Sans Mono, Courier New, monospace, serif;
    --background-color:        var(--gb-dm-bg0);
    --page-width:              60em;
    --font-color:              var(--gb-dm-fg1);
    --invert-font-color:       var(--gb-dm-bg0-hard);
    --primary-color:           var(--gb-dm-light-yellow);
    --secondary-color:         var(--gb-dm-fg3);
    --tertiary-color:          var(--gb-dm-light-gray);
    --error-color:             var(--gb-dm-light-red);
    --progress-bar-background: var(--gb-dm-bg2);
    --progress-bar-fill:       var(--gb-dm-fg2);
    --code-bg-color:           var(--gb-dm-bg2);
    --input-style:             solid;
    --display-h1-decoration:   none;
}