<link rel="icon" type="image/png" sizes="192x192" href="{{ 'img/android-chrome-192x192.png' | url }}" />
<link rel="icon" type="image/png" sizes="512x512" href="{{ 'img/android-chrome-512x512.png' | url }}" />
<link rel="apple-touch-icon" sizes="180x180" href="{{ 'img/apple-touch-icon.png' | url }}" />
<link rel="shortcut icon" type="image/png" sizes="48x48" href="{{ 'img/favicon.ico' | url }}" />
<link rel="icon" type="image/png" sizes="16x16" href="{{ 'img/favicon-16x16.png' | url }}" />
<link rel="icon" type="image/png" sizes="32x32" href="{{ 'img/favicon-32x32.png' | url }}" />